Module: Neruda::OrgFileHtmlizer
- Included in:
- OrgFile
- Defined in:
- lib/neruda/org_file/htmlizer.rb
Overview
This module holds HTML formatter methods for the OrgFile class.
Instance Method Summary collapse
-
#publish ⇒ Boolean?
Publish the current file or the entire project if @file is ~nil~.
Instance Method Details
#publish ⇒ Boolean?
Publish the current file or the entire project if
{Neruda::OrgFile#file @file} is ~nil~.
14 15 16 17 18 |
# File 'lib/neruda/org_file/htmlizer.rb', line 14 def publish Neruda::Emacs.new( file_path: @file, verbose: [:verbose] ).publish end |