Module: Neruda::OrgFileHtmlizer
- Included in:
- OrgFile
- Defined in:
- lib/neruda/org_file/htmlizer.rb
Overview
This module holds HTML formatter methods for the OrgFile class.
Instance Method Summary collapse
-
#publish ⇒ Boolean?
Publish the current file or the entire project if @file is ~nil~.
Instance Method Details
#publish ⇒ Boolean?
Publish the current file or the entire project if
{Neruda::OrgFile#file @file} is ~nil~.
13 14 15 16 17 18 19 20 |
# File 'lib/neruda/org_file/htmlizer.rb', line 13 def publish if @file.nil? emacs_args = ['--eval \'(org-publish "website")\''] else emacs_args = ['-f org-publish-current-file'] end call_emacs emacs_args end |